.. Copyright (C) 2020 Pedro Luis Lopez <pedroluis.lopezsanchez@gmail.com>
.. Copyright (C) 2020 Innobyte Bechea Leonardo <https://www.innobyte.com/>
.. Copyright (C) 2020 Innobyte Alin Alexandru <https://www.innobyte.com/>
.. Copyright (C) 2020 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _debops.influxdb_server:

debops.influxdb_server
======================

.. include:: man_description.rst
   :start-line: 9

.. toctree::
   :maxdepth: 2

   getting-started
   defaults-detailed
   defaults/main

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/influxdb_server/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
